pub struct Interpreter;Expand description
Public script verifier. Legacy and segwit-v0 spends use bitcoinconsensus when that backend is enabled; taproot key-path spends use the local BIP341 path.
Implementations
Sourceimpl Interpreter
impl Interpreter
Sourcepub const BATCH_SCHNORR_THRESHOLD: usize = 16
pub const BATCH_SCHNORR_THRESHOLD: usize = 16
Number of taproot inputs at which block validation uses the batch Schnorr path.
Sourcepub fn execute(
&self,
script_pubkey: &[u8],
script_sig: &[u8],
witness: &[Vec<u8>],
flags: VerifyFlags,
prevout: &TxOut,
tx: &Transaction,
input_idx: usize,
) -> Result<bool, ScriptError>
pub fn execute( &self, script_pubkey: &[u8], script_sig: &[u8], witness: &[Vec<u8>], flags: VerifyFlags, prevout: &TxOut, tx: &Transaction, input_idx: usize, ) -> Result<bool, ScriptError>
Executes a script spend through the enabled script backend.