verify_taproot_scriptpath

Function verify_taproot_scriptpath 

pub fn verify_taproot_scriptpath(
    signature: &Signature,
    message: &Message,
    public_key: &XOnlyPublicKey,
) -> bool
Verifies a tapscript Schnorr signature.

BIP342 changes the message construction and script rules, but the final Schnorr verification primitive is identical to key-path verification.