ScriptError

Enum ScriptError 

pub enum ScriptError {
    InputIndexOutOfRange {
        index: usize,
        inputs: usize,
    },
    UnknownFlag {
        name: String,
    },
    Serialization(String),
    Verification(String),
    TaprootPrevoutsUnavailable,
    TaprootUnsupportedWitness {
        elements: usize,
    },
}
Script execution errors surfaced by the script crate.

Variants



InputIndexOutOfRange

The requested input index was not present in the transaction.

Fields

index: usize

Requested input index.

inputs: usize

Transaction input count.



UnknownFlag

A Core vector flag name was not known by this crate.

Fields

name: String

Unknown flag name.



Serialization(String)

The transaction could not be serialized for the delegated verifier.



Verification(String)

The delegated consensus verifier rejected the script.



TaprootPrevoutsUnavailable

Taproot key-path verification requires all prevouts for multi-input transactions.



TaprootUnsupportedWitness

This portable path only validates one-element Taproot key-path witnesses.

Fields

elements: usize

Number of witness elements supplied for the P2TR spend.